def add(a, b):
    return a + b
def multiply(a, b):
    return a * b
def substract(a, b):
    return a - b
def divide(a, b):
    return a / b

def upgrade():
    return "Version 0.0.2..."